from .__pytransform import pyarmor_runtime

"""
# MixtureMapping

[![Documentation](https://github.com/VK/dash-express-components/workflows/Publish%20release/badge.svg)](https://vk.github.io/mixturemapping-doc)
[![PyPI version](https://badge.fury.io/py/mixturemapping.svg)](https://badge.fury.io/py/mixturemapping)

Train Gaussian Mixture Mappings


## Provides:
  1. Layers to build tensorflow models to map Gaussian mixtures
  2. Tools to compute yield values of Gaussian mixtures in complex binning schemes

## Example
  
    import mixturemapping as mm  
    import tensorflow as tf

    inMeans = tf.keras.Input(shape=(mixN, inputMixM), name="Means", dtype=dataType)
    inStdDevs = tf.keras.Input(shape=(mixN, inputMixM), name="StdDevs", dtype=dataType)
    inWeight = tf.keras.Input(shape=(mixN), name="Weights", dtype=dataType)

    mapModel = tf.keras.Sequential()
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(outputMixM))
    y = mapModel(inMeans)

    deltaModel = tf.keras.Sequential()
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(outputMixM))
    yDelta = deltaModel(inMeans)

    covALayer = mm.layers.TrainableCovMatrix(outputMixM, name="CovA")
    covA = covALayer(inMeans)

    mapLayer = mm.layers.GeneralMapping(outputMixM, name="Mapping", dtype=dataType)
    newDist = mapLayer({'means': inMeans, 'y':y, 'yDelta':yDelta, 'stdDevs': inStdDevs, 'weights': inWeight, 'covA': covA})

    distLayer = mm.layers.Distribution(dtype=dataType, regularize_cov_epsilon=0.95)
    dist = distLayer(newDist)

### Developement
```
$ py -m venv env
$ .\env\Scripts\activate
$ pip install -r requirements.txt
```


"""


pyarmor_runtime()
__pyarmor__(__name__, __file__, b'\x50\x59\x41\x52\x4d\x4f\x52\x00\x00\x03\x08\x00\x55\x0d\x0d\x0a\x08\x2d\xa0\x01\x00\x00\x00\x00\x01\x00\x00\x00\x40\x00\x00\x00\x9b\x08\x00\x00\x00\x00\x00\x18\x38\x1b\xdf\x97\xe2\xda\x8e\xd8\x4d\xb8\x1f\xad\x54\x23\xe7\xba\x00\x00\x00\x00\x00\x00\x00\x00\x23\x3e\xfb\x9c\xd5\x35\x8a\x3a\x20\xbd\x4a\x90\xe7\xde\xdd\x11\x7b\xd7\x09\x44\xc2\x93\x1f\x58\xce\x97\x99\x4b\xf4\x71\xad\x38\x80\x73\xca\xaf\x2f\xf9\x20\xf1\x85\x8e\xd1\x21\x1c\x9d\x6e\xf2\xe2\xaa\x6d\xfc\xe7\x28\xae\xdc\xa4\xf7\xd2\xd2\xd6\x07\x09\xd1\x87\x71\x1f\xae\xfb\xd5\xdf\x34\xcb\xf6\xdd\x1c\xb8\x23\x33\x7b\xc7\x0a\x44\xe6\xe5\x2e\x9b\xcf\x7e\x89\x25\x04\xc0\xcc\xc8\xd3\x93\xcf\xfd\x09\x39\x10\x3a\x24\x8e\x3d\xf6\x62\xe7\x6a\xd7\xae\x39\x51\xe9\x15\x10\x31\xbc\x24\xb4\xf1\xe5\x0f\xf6\x4f\x98\x1a\x45\x11\xaf\x6c\xbf\x5f\x8f\x7c\xec\x9e\x0d\x91\xa2\xb0\x42\x57\x78\x85\x40\x64\xf2\x61\x9c\x67\x92\x48\x3d\x8d\x0a\x85\x25\x69\x9c\xb0\xc4\x4a\x55\xc9\xd6\x69\x7c\xe1\x02\x3d\x8e\xc0\x29\x44\x01\x91\x74\xdd\xdb\xdd\xff\xe1\x80\xf0\x8f\x94\x69\x05\x41\x8e\xe6\xf8\x4a\x79\xaa\x0c\x8e\xd1\x3d\x5c\xc3\x88\xb0\xc6\x8a\x87\x83\x52\x51\xfc\x4a\xe3\x04\x0c\xc5\x49\x81\x78\xa6\x4a\xe8\x8b\x3c\xc7\xd1\x5c\x31\xc6\xf7\x88\x22\x29\x90\x34\xc1\x56\xa8\x88\xf8\x9b\xa7\x43\x7a\x70\x60\x5b\xa8\xbc\x2d\x25\x5b\xb0\xd5\x50\x53\x76\x2f\x23\xd3\xfa\x72\x27\x85\x8d\x03\xc0\x9a\xb6\x4b\xfd\xf3\x6f\xc5\xc8\x97\x1c\xe5\x21\xd6\x37\xb1\x01\x1d\x28\xc8\xb5\x27\xc6\x98\x17\xd2\x31\x66\x88\xa9\xf2\xb6\xc7\xcb\xa9\x95\xa2\x3c\x9c\x4f\x1b\x25\x8b\xb3\xf9\x45\xea\xc3\xf8\xcb\xef\x90\x61\xfe\x2f\x53\x9e\x32\xf0\x34\x21\x0e\xb9\x9c\xcc\xfd\x53\xe8\x32\x7d\xa1\xfb\xe3\x58\xb1\x1b\x3c\xec\xd8\xed\xee\x08\x68\xe5\x1e\x8a\x92\x74\x12\xca\x45\x67\xe9\x97\x2f\x8f\xeb\x3d\x1a\x33\x3b\x82\xcd\xd0\x97\x89\x76\x4f\xea\x43\xe8\x36\xa1\x73\xf6\x7f\x5d\x5a\x75\x36\x1e\xc3\x9f\x60\x33\xee\x6a\x26\x99\x7e\x91\x92\xd9\xbf\xf5\xd5\x70\x76\x46\x9b\x38\xef\x8d\x0e\xf7\x3c\x0c\x67\xa7\x2e\x78\xf7\x23\xdd\xa3\xa7\x61\x5b\xa7\x6d\xdc\x1f\x76\x16\x99\xe2\x25\x57\xb4\x24\x4e\x09\x2d\x67\xb6\x67\xda\x44\xb0\xa8\x9c\xf3\xfd\x7d\xb4\xea\xaa\xac\x36\x92\xb1\xd7\xc2\x8a\xfc\x3f\x56\x6f\x7d\x89\x60\x6c\x5c\x83\xc4\xc1\xca\x34\xad\x71\xe5\x14\x1d\x42\x52\xd0\xbb\xa5\x31\x07\x9d\x62\x62\xd4\x12\x28\xec\x4e\x17\x69\x17\xf4\x35\xe6\x7b\xf3\xf9\xca\x24\xe7\x2e\xc2\x05\xc2\x56\x36\x9f\x4f\x3d\x6d\x98\x8d\x61\x2e\x0e\x54\x06\x32\xde\x24\x27\x39\xf9\x7f\x51\x6e\x2a\xc4\x5b\xcc\xfe\x4d\xdd\x47\xf2\xbf\xd1\xfb\x07\x50\x1a\xd4\x1d\x3f\x19\xf7\xb6\x61\xec\x31\x20\x6c\x44\xf5\xe2\x33\x3c\x6e\xa3\xce\x1c\x4b\x1b\x8a\x2e\x83\x65\xa9\xa8\x6e\x82\x7b\x09\x93\x0d\x2c\x74\x53\x5a\xec\x66\xd1\xf3\xa5\x21\x17\xb9\x0f\x4c\x7e\x7d\x88\x41\xa1\x88\xb8\x85\x89\x43\xc7\x84\xea\x61\xc0\x06\xc3\x36\xad\xf4\x74\x4c\x75\x09\xa2\x7d\xba\xe6\x01\x3c\xd0\x8d\xc1\x6b\x7a\x7b\x4c\x43\xa2\x84\x62\xce\xbf\x3f\xec\xdc\x58\x75\xcf\x6c\x12\x2f\xbf\x21\x0b\x0b\xf9\x66\x24\xb6\x7f\xdd\x87\x94\xfc\xf0\xc8\x3e\x36\x6e\x64\x82\x2b\xd6\xfb\x02\x43\x41\xfa\x03\x5c\xfa\x67\x11\x4f\x48\xea\xf5\x0d\xb7\x64\x4f\xf6\xf0\xc7\xfb\x41\xe2\x94\x1c\x4a\x9a\x8b\x73\x57\x43\xe1\x93\x58\x52\xd0\x78\x53\x65\x4b\x77\x53\x89\xc8\xa0\xd9\x48\xca\x51\x08\x10\xed\x50\x3c\x6d\x50\xcd\x3f\xf8\x20\x30\x29\x77\xea\x40\xa5\xb2\x7e\x2e\xdb\x94\x44\x29\x03\xa9\xf8\xbe\x6e\x8d\x98\x9b\xb6\x81\x3a\x8d\x45\x94\x08\x7f\x38\x99\xf7\x84\x07\x57\xff\x87\x9d\xad\x59\x87\xeb\x7e\xaf\x73\xe2\xd6\xd1\x08\x97\x56\xa8\x90\x5e\xe2\xde\x4d\x3e\xb7\xbf\xaf\x3e\x12\xfb\xee\x88\x60\x7f\x44\x0c\x66\x57\x41\x9e\x30\xad\x55\x28\x48\x6d\x17\xd1\xf4\xe8\xcb\xb1\x29\x4e\x42\x85\x9b\xec\xb9\xf2\x0c\xd9\xb0\xec\x2c\x7f\x33\xdc\x0a\x22\x00\xb5\xe2\x9b\x68\xc3\x65\x5a\xb7\x25\x63\x12\x1c\x1c\x90\x1c\x61\xea\x6f\xcb\x0b\xd8\xc0\x93\x37\x32\x98\x98\x3a\x15\x20\x93\x5a\x0d\xa6\x34\xa8\x32\xb1\x5f\xdc\x8d\x1e\x75\xc1\x09\x87\x5a\x59\xf2\xc6\xe7\x16\xe7\x2a\x9c\xc3\x4f\xcb\x2b\xbd\x48\xee\xe8\x13\x22\xb4\xb7\x86\x90\xee\x0f\x4b\x2c\x9e\x39\xb4\x5f\xa5\x4f\xa8\xaa\xbc\xa4\x07\xa8\x50\x0c\x42\x3d\xa0\x67\xfa\x11\x67\xd4\x5a\xfb\x87\x76\x08\x35\x70\xb1\x27\xa3\x89\x56\x6d\xab\xea\xa9\xc7\x1d\x8f\x89\x79\xe2\xdf\xda\x7c\xb9\x79\x69\xe7\x98\xd9\xf4\xa0\xf5\x95\x6d\xee\x2c\x99\x6d\x26\x0f\x96\x5c\x99\xc9\x28\x93\x41\xef\x51\x67\x07\xba\x5a\x06\x60\x3f\x6f\x81\x1e\xe3\x83\xc9\xb9\x1e\xdd\x7e\xce\xf5\xa2\x70\x25\x68\x2a\x6a\xca\x29\xf1\x5c\xad\x31\x29\x58\xea\x83\xa1\xa2\x31\xc5\x0b\xeb\xba\x7b\x8d\x06\xfb\xc2\x02\x74\x25\x21\xa4\xac\x22\x88\xef\xa4\x6c\xd1\x49\x5b\xe2\xfe\x2f\x14\xf8\xa2\xb9\xc9\x62\x25\xcb\xd1\xb8\x32\x56\xc6\x4b\x5d\xd2\xfb\x2d\xa6\x23\x82\x86\x0e\x16\x9b\xf5\x53\x43\x84\x3b\x36\x2d\x27\x02\xd2\x99\x2a\x63\xdd\xf6\xfb\x98\x88\x02\xbb\xc2\xd1\xab\x90\x29\x31\xd7\xcb\x2b\x0b\x34\x0c\x11\x60\xe6\x2f\x16\x01\x6f\x0c\xb9\xb7\x7a\x35\xbb\xc3\xce\xc1\x7e\x41\xe8\x67\x04\x6f\x29\xea\x5a\xa7\x33\x66\x57\xee\xe0\xf1\x58\x9a\x98\x1a\x5c\x0b\x10\xab\xe0\x0b\xe0\xaa\x9b\x2b\x79\xf9\x55\x9a\x36\x22\xe2\x18\x63\x4d\xed\x9e\x07\xcd\x21\xe2\x06\x48\x3a\x72\xaa\xa2\x67\xf5\x97\x46\x3b\xb8\xc9\x16\x7d\x5b\xe9\x9b\x78\x69\x2a\xd1\x10\x83\xeb\x85\xa3\x1b\x59\x51\x8d\xf2\xb0\x47\x86\x30\x64\x07\xf7\x96\xfa\x96\x01\x72\xb6\x3b\xb9\x96\x95\x0b\x40\xb4\xc8\xd7\x10\x9e\xe6\x1c\x08\x25\xcb\x4f\x35\x0a\x50\x96\x74\x80\x69\xf2\x89\xde\x15\xc8\x37\x9e\x97\xf7\x31\x22\x8d\xb4\x80\xf1\x2a\xa6\x4c\x76\x78\x7e\x89\x46\x26\xf2\xd2\x9e\x51\xbc\x45\x4b\x29\x04\xe9\x61\xdc\x19\x00\x48\x79\xe1\x8f\x8a\x26\xa9\xdb\x42\xa8\x95\x69\xf7\xad\x81\x61\x0f\x2f\x28\x38\x81\xdc\xbd\xda\xb6\x49\x19\xbd\x06\xf6\x03\x12\x9b\x0a\x54\x4c\x89\x05\x36\xae\xbc\xee\x55\x6e\xcd\xf1\x27\x78\x6d\x54\x07\x6a\x6a\x97\x76\xe9\x74\xdd\x6b\xcc\x66\xea\x99\x7c\x9c\x45\xc8\x47\x26\x70\xcc\x4a\x8f\xf3\x8e\xcf\xb9\x5a\xdc\x31\x96\x62\x91\xb5\xc4\xef\x45\x11\x72\x96\xaa\x35\xec\x7c\xed\xc2\x38\xd4\x90\x74\x18\x52\xd5\x71\x07\x6c\xae\xd5\x07\xb0\x03\xb1\x09\x4e\xc1\xc2\xa3\x44\xc7\x60\x95\xd7\xea\xc5\x26\x8c\xcb\x58\x1a\xa6\xc7\xc2\x40\xdb\x1f\x16\x05\x4d\x9a\x72\x31\x7b\x11\xcb\x36\x2d\xfd\xb7\x54\x38\xfa\x46\x14\x88\xe5\x8e\x7e\xc6\x54\x73\xda\x8a\x4d\x18\xa8\x1d\xc2\x0b\xc8\x46\x08\x1f\x79\xa9\x39\x59\x29\x36\x31\x55\x6a\x7a\x74\x6e\x43\x65\x79\x1a\xcb\xdf\xb5\xf5\x84\x80\x0f\x90\xf2\x94\xb0\x9a\xcb\x73\x12\xf7\xd6\xa8\x08\xe7\x21\x8c\x14\xa5\xd3\x8b\x5b\xcb\xf2\x70\xc3\xe1\xc1\x44\xf8\xb7\x93\x00\x3f\x31\xc4\x3d\xe4\xf2\x1f\xec\xe3\xbf\x37\x39\x5d\xcd\x45\x5b\x65\x63\xff\xe1\x98\x9e\xad\xfa\xd4\x76\x1d\xb5\xb3\x2f\xfe\xdc\x9a\x4f\xa9\x75\x7b\x78\xb0\x61\xef\x79\x2d\xee\x0d\x53\x29\x52\x23\xd0\x5f\x4b\xfc\xcd\x68\x69\x43\x4b\xbe\x5d\x89\xcc\x30\x67\x53\x8d\x1d\xba\xdd\x12\x8c\xe3\x3b\x9a\xc9\x0d\xf8\x4c\xc0\x3c\x6b\x92\x41\xe4\x39\x51\xf3\x17\x22\x2c\xcd\x5d\x1f\xf1\x99\x6d\x6e\xe5\x60\x38\xe9\x5e\x08\x23\x82\xbb\x63\xab\x2b\x3e\xee\x06\x0d\xac\x46\x1b\x4f\x1d\xfb\x8f\x60\x6e\x78\xad\xf0\xdc\x3e\x5a\x21\xd7\x1e\x02\xd0\x0f\x12\xba\x4d\x39\x6b\x33\xcb\x8e\x73\xd0\x51\xaa\x27\xb9\x0b\x67\x41\xf7\xde\x3d\x78\x44\x99\xa4\x22\x77\x51\x76\xaa\x88\x84\xd8\x45\xd0\x61\x13\x09\xf8\xb5\x3a\x47\xd4\x79\x55\x7e\x09\x6d\x94\xb8\xa8\x6a\xbc\x21\x9a\x10\xf2\x03\x5e\x24\x69\x61\x56\xd6\xa4\x80\x1a\xe4\xa5\xe0\x2f\x63\x19\x58\x44\xb3\x55\xc0\xee\x82\xee\x1b\x42\x83\x17\x8f\x60\x20\x2a\x89\x9a\x08\x6c\xd8\x36\x35\x33\xca\x7e\x8e\x24\xf4\x9c\x32\x6f\x79\xb5\xaf\xc4\x59\x2c\xa8\x5a\x40\x4a\x52\x5d\x63\x23\x4a\x9d\xfb\xb7\xc3\xf3\xe9\xda\xbe\x24\xb6\xca\x07\x28\xea\xca\x9e\xb6\xed\x69\xfa\xdf\x5f\x81\xa6\x67\xfc\x35\x25\xe1\x5e\x75\x86\x65\x4d\xdc\xdf\xd4\xd3\x85\x0c\x1c\xba\x5f\x08\x85\x72\xef\x02\x09\xf5\x79\xe5\x3d\x1c\xce\xc8\x6c\xa5\x2c\x24\xd3\x86\xfa\x76\x54\x84\x85\xe9\x34\x33\x5d\x2d\xd0\xe8\x03\xef\x83\x58\xe8\xfa\xd8\xf5\x06\xf2\x86\xc0\xf6\xe9\x21\xe2\x3a\xdd\xce\x60\x58\x43\x34\x08\x2d\x95\xc3\xd6\x40\x83\x26\x59\x37\x50\xc2\xbc\x92\x3b\xa8\xeb\xc9\xa9\xab\x48\x04\xea\x71\xfc\xe3\x39\x9d\xa5\x71\xb5\x24\xe6\x4f\xdd\xc5\xf2\xbb\x2e\x05\xa6\x0e\x56\x98\xa6\x9c\x7a\x4e\xed\x4e\xc3\xe7\xbc\xac\x58\xbd\x05\x6b\xdd\x49\x78\x8b\xd5\x83\x9b\x10\x46\x82\x37\xca\xbb\x3d\x76\x0e\x3e\xa3\x9a\x01\x1b\x11\xe1\x99\x57\xed\x01\xa8\xd8\x4b\x30\x9c\xfc\x2e\xb5\xe4\xad\x66\xab\xb2\x0d\x52\xe6\xb1\xe1\x3c\x27\x68\x98\x80\x06\x32\x49\x10\x9f\x48\x94\x18\x8d\xf3\x9d\xe6\xa6\xb3\x19\x4c\xc6\xd6\x2e\xff\x17\x00\xad\xc0\x21\x3c\x33\xf8\xd1\x5a\x2f\x9c\xf9\x97\xe1\xfc\x87\x5b\x4f\xe3\x0f\x01\x8b\xef\x99\x8b\xb4\x1c\x30\x07\xe1\xd0\x98\x9b\x05\x12\xea\x3c\x28\xa7\xa4\x12\x97\xb4\x30\x0b\x63\x3a\xba\x10\x9a\xbe\xe1\xc0\x37\xb1\x60\x47\x7d\xdb\x61\x78\xf7\x5e\x88\x6a\x2f\xe0\x16\x2b\x52\x65\xe3\x61\x92\x59\x1f\xf7\x2c\x31\x47\xb6\x65\xd5\x5c\x82\x43\x82\xa8\x01\x7c\x5a\xbe\xb5\x25\x20\xfc\xe5\xda\x98\xf1\xfc\x2d\x09\x08\xd4\xf0\x59\x18\x4f\x02\x9f\xe2\xdd\xce\x42\xf7\x9a\x02\x31\xe1\xa6\x8c\xa4\xc2\x69\x45\x19\xf6\xff\x9b\x35\x1a\xd7\xf2\x78\x87\x72\xd1\xc4\xfb\x4b\xf1\xa0\xaf\x8c\xa8\xd3\x42\x37\x10\x8b\x15\x4f\xfd\x05\xff\x8d\xfc\xd7\xe3\x50\x62\x57\x82\x91\x14\x5d\xad\x86\x4c\x70\x14\x33\x8d\x6e\xb7\x48\x44\xf9\xb3\xb7\x3c\x81\x43\x06\xc3\x76\xfa\x5b\xc4\xcd\xa4\x17\x5b\x35\x8b\x9d\x03\x23\xdb\x0d\x00\xd9\x95\xc2\x58\xa8\x37\x23\x71\x27\xaa\x3c\x0c\xb6\xc3\xd0\x84\xd0\xc7\x62\xda\x96\x8e\x27\xcd', 2)

# cleanup
del pyarmor_runtime

